create_custom_events

Function create_custom_events 

pub async fn create_custom_events(
    configuration: &Configuration,
    app_id: &str,
    custom_events_request: CustomEventsRequest,
) -> Result<Value, Error<CreateCustomEventsError>>
The Custom Events API allows you to record user events. Custom events can represent any action users take in your application, such as completing a purchase, viewing content, or achieving milestones.