pub async fn get_segment(
configuration: &Configuration,
app_id: &str,
segment_id: &str,
include_segment_detail: Option<bool>,
) -> Result<GetSegmentSuccessResponse, Error<GetSegmentError>>Expand description
Retrieve details for a single segment by its ID, including subscriber count and optionally segment metadata and filters.