pub struct Filter {
pub field: Option<String>,
pub key: Option<String>,
pub value: Option<String>,
pub hours_ago: Option<String>,
pub radius: Option<f32>,
pub lat: Option<f32>,
pub long: Option<f32>,
pub relation: Option<RelationType>,
}Fields
field: Option<String>Required. Name of the field to use as the first operand in the filter expression.
key: Option<String>If field is tag, this field is required to specify key inside the tags.
value: Option<String>Constant value to use as the second operand in the filter expression. This value is required when the relation operator is a binary operator. For in_array and not_in_array relations, provide a comma-separated list of up to 20 values.
hours_ago: Option<String>If field is session-related, this is required to specify the number of hours before or after the user’s session.
radius: Option<f32>If field is location, this will specify the radius in meters from a provided location point. Use with lat and long.
lat: Option<f32>If field is location, this is required to specify the user’s latitude.
long: Option<f32>If field is location, this is required to specify the user’s longitude.
relation: Option<RelationType>Required. Operator of a filter expression.