SegmentDetails

Struct SegmentDetails 

pub struct SegmentDetails {
    pub id: Option<String>,
    pub name: Option<String>,
    pub description: Option<String>,
    pub created_at: Option<i32>,
    pub source: Option<SourceType>,
    pub filters: Option<Vec<FilterExpression>>,
}
SegmentDetails : Segment details. Only included when the include-segment-detail query parameter is set to true.

Fields

id: Option<String>

The unique identifier for the segment (UUID v4).

name: Option<String>

The segment name.

description: Option<String>

Human-readable description for the segment. null when unset. Maximum 255 characters.

created_at: Option<i32>

Unix timestamp when the segment was created.

source: Option<SourceType>

The source of the segment.

filters: Option<Vec<FilterExpression>>

Array of filter and operator objects defining the segment criteria. Uses the same format as the Create Segment API, so filters can be directly used to recreate or update the segment.

Implementations

Source

impl SegmentDetails

pub fn new() -> SegmentDetails

Segment details. Only included when the include-segment-detail query parameter is set to true.