pub async fn create_custom_events(
configuration: &Configuration,
app_id: &str,
custom_events_request: CustomEventsRequest,
) -> Result<Value, Error<CreateCustomEventsError>>Expand description
The Custom Events API allows you to record user events. Custom events can represent any action users take in your application, such as completing a purchase, viewing content, or achieving milestones.