get_segment

Function get_segment 

pub async fn get_segment(
    configuration: &Configuration,
    app_id: &str,
    segment_id: &str,
    include_segment_detail: Option<bool>,
) -> Result<GetSegmentSuccessResponse, Error<GetSegmentError>>
Retrieve details for a single segment by its ID, including subscriber count and optionally segment metadata and filters.