pub struct StartLiveActivityRequest {Show 16 fields
pub name: String,
pub event: EventType,
pub activity_id: String,
pub event_attributes: Value,
pub event_updates: Value,
pub contents: Box<LanguageStringMap>,
pub headings: Box<LanguageStringMap>,
pub stale_date: Option<i32>,
pub priority: Option<i32>,
pub ios_relevance_score: Option<f32>,
pub idempotency_key: Option<String>,
pub include_aliases: Option<HashMap<String, Vec<String>>>,
pub include_subscription_ids: Option<Vec<String>>,
pub included_segments: Option<Vec<String>>,
pub excluded_segments: Option<Vec<String>>,
pub filters: Option<Vec<FilterExpression>>,
}Fields
name: StringAn internal name to assist with your campaign organization. This does not get displayed in the message itself.
event: EventTypeactivity_id: StringSet a unique activity_id to track and manage the Live Activity.
event_attributes: ValueDefault/static data to initialize the Live Activity upon start.
event_updates: ValueDynamic content used to update the running Live Activity at start. Must match the ContentState interface defined in your app.
contents: Box<LanguageStringMap>headings: Box<LanguageStringMap>stale_date: Option<i32>Accepts Unix timestamp in seconds. When time reaches the configured stale date, the system considers the Live Activity out of date, and the ActivityState of the Live Activity changes to ActivityState.stale.
priority: Option<i32>Delivery priority through the push provider (APNs). Pass 10 for higher priority notifications, or 5 for lower priority notifications. Lower priority notifications are sent based on the power considerations of the end user’s device. If not set, defaults to 10.
ios_relevance_score: Option<f32>iOS 15+. A score to indicate how a notification should be displayed when grouped. Use a float between 0-1.
idempotency_key: Option<String>Correlation and idempotency key. A request received with this parameter will first look for another notification with the same idempotency key. If one exists, a notification will not be sent, and result of the previous operation will instead be returned. Therefore, if you plan on using this feature, it’s important to use a good source of randomness to generate the UUID passed here. This key is only idempotent for 30 days. After 30 days, the notification could be removed from our system and a notification with the same idempotency key will be sent again. See Idempotent Notification Requests for more details writeOnly: true
include_aliases: Option<HashMap<String, Vec<String>>>Target specific users by aliases assigned via API. An alias can be an external_id, onesignal_id, or a custom alias. Accepts an object where keys are alias labels and values are arrays of alias IDs to include Example usage: { "external_id": ["exId1", "extId2"], "internal_label": ["id1", "id2"] } Not compatible with any other targeting parameters. REQUIRED: REST API Key Authentication Limit of 2,000 entries per REST API call Note: If targeting push, email, or sms subscribers with same ids, use with target_channel to indicate you are sending a push or email or sms.
include_subscription_ids: Option<Vec<String>>Specific subscription ids to target. Not compatible with other targeting parameters.
included_segments: Option<Vec<String>>Segment names to include. Only compatible with excluded_segments.
excluded_segments: Option<Vec<String>>Segment names to exclude. Only compatible with included_segments.
filters: Option<Vec<FilterExpression>>Implementations
Sourceimpl StartLiveActivityRequest
impl StartLiveActivityRequest
pub fn new( name: String, event: EventType, activity_id: String, event_attributes: Value, event_updates: Value, contents: LanguageStringMap, headings: LanguageStringMap, ) -> StartLiveActivityRequest